@@ -34,44 +34,38 @@
 #include <QGraphicsProxyWidget>
 
 //const int CORNER_WITH = 20;
-
+REGISTITEMCLASS(CGraphicsCutItem, CutType)
 CGraphicsCutItem::CGraphicsCutItem(CGraphicsItem *parent)
     : CGraphicsItem(parent)
     , m_isFreeMode(false)
 {
-    initHandle();
     Q_UNUSED(nodes());
 }
 
 CGraphicsCutItem::CGraphicsCutItem(const QRectF &rect, CGraphicsItem *parent)
     : CGraphicsItem(parent),
       m_topLeftPoint(rect.topLeft()),
-      m_bottomRightPoint(rect.bottomRight()),
-      m_originalRect(QPoint(0, 0), CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getCutDefaultSize())
+      m_bottomRightPoint(rect.bottomRight())
     , m_isFreeMode(false)
 {
-    initHandle();
-    CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->setCutSize(rect.size().toSize());
+    setOriginalRect(rect);
 }
 
-//CGraphicsCutItem::CGraphicsCutItem(qreal x, qreal y, qreal w, qreal h, CGraphicsItem *parent)
-//    : CGraphicsItem(parent)
-//    , m_isFreeMode(false)
-//{
-//    QRectF rect(x, y, w, h);
-//    rect = rect.normalized();
-//    m_topLeftPoint = rect.topLeft();
-//    m_bottomRightPoint = rect.bottomRight();
-//    m_originalRect = QRectF(0, 0, 0, 0);
-//    m_originalRect.setSize(CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getCutDefaultSize());
-//    initHandle();
-//}
-
 CGraphicsCutItem::~CGraphicsCutItem()
 {
 
 }
 
+SAttrisList CGraphicsCutItem::attributions()
+{
+    DrawAttribution::SAttrisList result;
+    QList<QVariant> vars;
+    vars << m_cutType << rect().size();
+    SAttri attri(DrawAttribution::ECutToolAttri, vars);
+    result << attri;
+    return result;
+}
+
 QPainterPath CGraphicsCutItem::shape() const
 {
     QPainterPath path;
@@ -91,11 +85,22 @@ int CGraphicsCutItem::type() const
 
 void CGraphicsCutItem::setRect(const QRectF &rect)
 {
+    // 裁剪区域最小为10x10
+    if (rect.width() < 10 || rect.height() < 10)
+        return ;
+
+    if (rect.width() > 10000 || rect.height() > 10000) {
+        return;
+    }
+
     prepareGeometryChange();
     m_topLeftPoint = rect.topLeft();
     m_bottomRightPoint = rect.bottomRight();
     updateHandlesGeometry();
-    CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->setCutSize(rect.size().toSize());
+
+    if (curView() != nullptr) {
+        curView()->setFocus();
+    }
 }
 
 void CGraphicsCutItem::initHandle()
@@ -172,23 +177,6 @@ void CGraphicsCutItem::move(QPointF beginPoint, QPointF movePoint)
     setRect(rect().adjusted(adjust.x(), adjust.y(), adjust.x(), adjust.y()));
 }
 
-CSizeHandleRect::EDirection CGraphicsCutItem::hitTest(const QPointF &point) const
-{
-    const Handles::const_iterator hend =  m_handles.end();
-    for (Handles::const_iterator it = m_handles.begin(); it != hend; ++it) {
-        if ((*it)->hitTest(point)) {
-            return (*it)->dir();
-        }
-    }
-    //检测是否在矩形内
-    QPointF pt = mapFromScene(point);
-    if (this->rect().contains(pt)) {
-        return CSizeHandleRect::InRect;
-    }
-
-    return CSizeHandleRect::None;
-}
-
 QPainterPath CGraphicsCutItem::getHighLightPath()
 {
     return QPainterPath();
@@ -216,10 +204,12 @@ void CGraphicsCutItem::setIsFreeMode(bool isFreeMode)
     showControlRects(true);
 }
 
+
 void CGraphicsCutItem::resizeCutSize(CSizeHandleRect::EDirection dir,
                                      const QPointF &prePoint,
                                      const QPointF &point, QPointF *outAcceptPos)
 {
+    Q_UNUSED(outAcceptPos)
     //得到在自身坐标系内的当前鼠标位置
     QPointF preLocalPos = mapFromScene(prePoint);
     QPointF curLocalPos = mapFromScene(point);
@@ -230,263 +220,172 @@ void CGraphicsCutItem::resizeCutSize(CSizeHandleRect::EDirection dir,
     qreal moveY = (curLocalPos - preLocalPos).y();
     qreal adjust[4] = {0, 0, 0, 0};
 
+    //bool getBorder = false;
 
-    bool getBorder = false;
+    /*
+     * fAdjustX 调整X轴上的位移
+     * moveX 移动的值
+     * currentRect 当前图元的rect(为了获取当前宽)
+     * max，min 允许的最大值和最小值
+     * directionX 移动的方向，需要传入-1或者1，1表示moveX是正值，-1表示是负值，请根据moveX的正负来传入
+    */
+    auto fAdjustX = [ = ](qreal & moveX, const QRectF & currentRect, qreal max, qreal min, int directionX = 1) {
+        qreal wantedW = currentRect.width() + directionX * moveX;
+        if (wantedW > max) {
+            wantedW = max;
+        } else if (wantedW < min) {
+            wantedW = min;
+        }
+        moveX = (wantedW - currentRect.width()) / directionX;
+    };
+    /*
+     * fAdjustY 调整Y轴上的位移
+     * moveY 移动的值
+     * currentRect 当前图元的rect(为了获取当前宽)
+     * max，min 允许的最大值和最小值
+     * directionY 移动的方向，需要传入-1或者1，1表示moveY是正值，-1表示是负值，请根据moveY的正负来传入
+    */
+    auto fAdjustY = [ = ](qreal & moveY, const QRectF & currentRect, qreal max, qreal min, int directionY = 1) {
 
-    qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-    qreal minH = (qWHRadio < 1.0 && qWHRadio > 0.0) ? 10 / qWHRadio : 10;
+        qreal wantedH = currentRect.height() + directionY * moveY;
+
+        if (wantedH > max) {
+            wantedH = max;
+        } else if (wantedH < min) {
+            wantedH = min;
+        }
+        moveY = (wantedH - currentRect.height()) / directionY;
+    };
+    /*
+     * fAdjustBase 调整X，Y轴上的位移
+     * moveX，moveY 移动的值
+     * currentRect 当前图元的rect(为了获取当前宽)
+     * baseXY 基于那个轴进行调整(0表示X轴，1表示Y轴)
+     * directionX，directionY 移动的方向，需要传入-1或者1，1表示move是正值，-1表示是负值，请根据move的正负来传入
+    */
+    auto fAdjustBase = [ = ](qreal & moveX, qreal & moveY, const QRectF & currentRect, int baseXY = 0, int directionX = 1, int directionY = 1) {
+
+        if (baseXY == 0) {
+
+            qreal maxW = 10000;
+            qreal minW = 10;
+
+            qreal maxH = qWHRadio > 0 ? maxW / qWHRadio : 10000;
+            qreal minH = qWHRadio > 0 ? minW / qWHRadio : 10;
+
+            fAdjustX(moveX, currentRect, maxW, minW, directionX);
+            if (qWHRadio > 0) {
+                moveY = (moveX * directionX * directionY) / qWHRadio;
+            }
+
+            fAdjustY(moveY, currentRect, maxH, minH, directionY);
+
+            if (qWHRadio > 0)
+                moveX = moveY * qWHRadio / (directionX * directionY);
+        } else {
+            qreal maxH = 10000;
+            qreal minH = 10;
+
+            qreal maxW = qWHRadio > 0 ? maxH * qWHRadio : 10000;
+            qreal minW = qWHRadio > 0 ? minH * qWHRadio : 10;
+
+            fAdjustY(moveY, currentRect, maxH, minH, directionY);
+
+            if (qWHRadio > 0) {
+                moveX = moveY * directionX * directionY * qWHRadio;
+            }
+
+            fAdjustX(moveX, currentRect, maxW, minW, directionX);
+
+            if (qWHRadio > 0)
+                moveY = moveX / qWHRadio * directionX * directionY;
+        }
+
+    };
 
-    //根据dir的位置判断应该改变到的大小
     switch (dir) {
     case CSizeHandleRect::Top: {
+        qreal mx = 0;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, 1, -1, -1);
         adjust[1] = moveY;
 
-        //边界检查
-        if (curRect.height() - adjust[1] < minH) {
-            adjust[1] = curRect.height() - minH;
-            getBorder = true;
-        }
-
-        if (qWHRadio > 0) {
-            adjust[2] = -adjust[1] * qWHRadio;
-        }
-        break;
-    }
-
-    case CSizeHandleRect::Bottom: {
-        adjust[3] = moveY;
-
-        //边界检查
-        if (curRect.height() + adjust[3] < minH) {
-            adjust[3] = minH - curRect.height();
-            getBorder = true;
-        }
-
-        if (qWHRadio > 0) {
-            adjust[2] = adjust[3] * qWHRadio;
-        }
-        break;
-    }
-    case CSizeHandleRect::Left: {
-        adjust[0] = moveX;
-
-        //边界检查
-        if (curRect.width() - adjust[0] < minW) {
-            adjust[0] = curRect.width() - minW;
-            getBorder = true;
-        }
-
-        if (qWHRadio > 0) {
-            adjust[3] = -adjust[0] / qWHRadio;
-        }
-
+        adjust[0] = mx / 2;
+        adjust[2] = -mx / 2;
         break;
     }
     case CSizeHandleRect::Right: {
-        adjust[2] = moveX;
-
-        //边界检查
-        if (curRect.width() + adjust[2] < minW) {
-            adjust[2] = minW - curRect.width();
-            getBorder = true;
-        }
-
-        if (qWHRadio > 0) {
-            adjust[3] = adjust[2] / qWHRadio;
-            getBorder = true;
-        }
+        qreal mx = moveX;
+        qreal my = 0;
+        fAdjustBase(mx, my, curRect, 0, 1, 1);
+        adjust[2] = mx;
+        adjust[1] = -my / 2;
+        adjust[3] = my / 2;
         break;
     }
-    case CSizeHandleRect::RightTop: {
-        if (qWHRadio > 0) {
-            if (qAbs(moveX) > qAbs(moveY)) {
-                adjust[2] = moveX;
-
-                //边界检查
-                //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-                if (curRect.width() + adjust[2] < minW) {
-                    adjust[2] = minW - curRect.width();
-                    getBorder = true;
-                }
-
-                adjust[1] = -adjust[2] / qWHRadio;
-            } else {
-                adjust[1] = moveY;
-
-                //边界检查
-                //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-                if (curRect.height() - adjust[1] < minH) {
-                    adjust[1] = curRect.height() - minH;
-                    getBorder = true;
-                }
-
-                adjust[2] = -adjust[1] * qWHRadio;
-            }
-        } else {
-
-            adjust[2] = moveX;
-            adjust[1] = moveY;
-
-            //边界检查
-            //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-            if (curRect.width() + adjust[2] < minW) {
-                adjust[2] = minW - curRect.width();
-                getBorder = true;
-            }
-
-            //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-            if (curRect.height() - adjust[1] < minH) {
-                adjust[1] = curRect.height() - minH;
-                getBorder = true;
-            }
-        }
-
+    case CSizeHandleRect::Bottom: {
+        qreal mx = 0;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, 1, 1, 1);
+        adjust[3] = moveY;
+        adjust[0] = -mx / 2;
+        adjust[2] = mx / 2;
+        break;
+    }
+    case CSizeHandleRect::Left: {
+        qreal mx = moveX;
+        qreal my = 0;
+        fAdjustBase(mx, my, curRect, 0, -1, -1);
+        adjust[0] = mx;
+        adjust[1] = my / 2;
+        adjust[3] = -my / 2;
         break;
     }
     case CSizeHandleRect::LeftTop: {
-        if (qWHRadio > 0) {
-            if (qAbs(moveX) > qAbs(moveY)) {
-                adjust[0] = moveX;
-                //边界检查
-                //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-                if (curRect.width() - adjust[0] < minW) {
-                    adjust[0] = curRect.width() - minW;
-                    getBorder = true;
-                }
-                adjust[1] = adjust[0] / qWHRadio;
-            } else {
-                adjust[1] = moveY;
-                //边界检查
-                //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-                if (curRect.height() - adjust[1] < minH) {
-                    adjust[1] = curRect.height() - minH;
-                    getBorder = true;
-                }
-                adjust[0] = adjust[1] * qWHRadio;
-            }
-        } else {
-            adjust[0] = moveX;
-            adjust[1] = moveY;
-
-            //边界检查
-            //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-            if (curRect.width() - adjust[0] < minW) {
-                adjust[0] = curRect.width() - minW;
-                getBorder = true;
-            }
-
-            //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-            if (curRect.height() - adjust[1] < minH) {
-                adjust[1] = curRect.height() - minH;
-                getBorder = true;
-            }
-        }
+        qreal mx = moveX;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, qAbs(mx) < qAbs(my), -1, -1);
+        adjust[0] = mx;
+        adjust[1] = my;
+        break;
+    }
+    case CSizeHandleRect::RightTop: {
+        qreal mx = moveX;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, qAbs(mx) < qAbs(my), 1, -1);
+        adjust[2] = mx;
+        adjust[1] = my;
         break;
     }
-
     case CSizeHandleRect::RightBottom: {
-        if (qWHRadio > 0) {
-            if (qAbs(moveX) > qAbs(moveY)) {
-                adjust[2] = moveX;
-
-                //边界检查
-                //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-                if (curRect.width() + adjust[2] < minW) {
-                    adjust[2] = minW - curRect.width();
-                    getBorder = true;
-                }
-
-                adjust[3] = adjust[2] / qWHRadio;
-            } else {
-                adjust[3] = moveY;
-
-                //边界检查
-                //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-                if (curRect.height() + adjust[3] < minH) {
-                    adjust[3] = minH - curRect.height();
-                    getBorder = true;
-                }
-
-                adjust[2] = adjust[3] * qWHRadio;
-            }
-        } else {
-            adjust[2] = moveX;
-            adjust[3] = moveY;
-
-            //边界检查
-            //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-            if (curRect.width() + adjust[2] < minW) {
-                adjust[2] = minW - curRect.width();
-                getBorder = true;
-            }
-
-            //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-            if (curRect.height() + adjust[3] < minH) {
-                adjust[3] = minH - curRect.height();
-                getBorder = true;
-            }
-        }
-
+        qreal mx = moveX;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, qAbs(mx) < qAbs(my), 1, 1);
+        adjust[2] = mx;
+        adjust[3] = my;
         break;
     }
-
     case CSizeHandleRect::LeftBottom: {
-        if (qWHRadio > 0) {
-            if (qAbs(moveX) > qAbs(moveY)) {
-                adjust[0] = moveX;
-
-                //边界检查
-                //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-                if (curRect.width() - adjust[0] < minW) {
-                    adjust[0] = curRect.width() - minW;
-                    getBorder = true;
-                }
-
-                adjust[3] = -adjust[0] / qWHRadio;
-            } else {
-                adjust[3] = moveY;
-
-                //边界检查
-                //qreal minH = qWHRadio < 1.0 ? 10 / qWHRadio : 10;
-                if (curRect.height() + adjust[3] < minH) {
-                    adjust[3] = minH - curRect.height();
-                    getBorder = true;
-                }
-
-                adjust[0] = -adjust[3] * qWHRadio;
-            }
-        } else {
-            adjust[0] = moveX;
-            adjust[3] = moveY;
-
-            //边界检查
-            //qreal minW = qWHRadio > 1.0 ? 10 * qWHRadio : 10;
-            if (curRect.width() - adjust[0] < minW) {
-                adjust[0] = curRect.width() - minW;
-                getBorder = true;
-            }
-
-            //qreal minH = qWHRadio < 1.0 ? 10 * qWHRadio : 10;
-            if (curRect.height() + adjust[3] < minH) {
-                adjust[3] = minH - curRect.height();
-                getBorder = true;
-            }
-
-        }
+        qreal mx = moveX;
+        qreal my = moveY;
+        fAdjustBase(mx, my, curRect, qAbs(mx) < qAbs(my), -1, 1);
+        adjust[0] = mx;
+        adjust[3] = my;
         break;
     }
-    default:
+    default: {
         break;
     }
-
-    if (outAcceptPos != nullptr) {
-        if (getBorder) {
-            *outAcceptPos = (prePoint + QPointF(adjust[0] + adjust[2], adjust[1] + adjust[3]));
-        } else {
-            *outAcceptPos = point;
-        }
     }
 
+//    if (outAcceptPos != nullptr) {
+//        if (getBorder) {
+//            *outAcceptPos = (prePoint + QPointF(adjust[0] + adjust[2], adjust[1] + adjust[3]));
+//        } else {
+//            *outAcceptPos = point;
+//        }
+//    }
+
     curRect.adjust(adjust[0], adjust[1], adjust[2], adjust[3]);
 
     prepareGeometryChange();
@@ -499,10 +398,10 @@ void CGraphicsCutItem::resizeCutSize(CSizeHandleRect::EDirection dir,
 qreal CGraphicsCutItem::getWHRadio()
 {
     qreal   qwhRadio    = -1;
-    CGraphicsView *pView = curView();
+    PageView *pView = curView();
     if (pView != nullptr) {
         if (!isFreeMode()) {
-            ECutType cutTp = pView->getDrawParam()->getCutType();
+            ECutType cutTp = getRatioType();
             switch (cutTp) {
             case cut_1_1:
                 qwhRadio = 1.0;
@@ -546,8 +445,8 @@ void CGraphicsCutItem::setRatioType(ECutType type)
     qreal bigH = h;
 
     if (type == cut_original) {
-        bigW = m_originalRect.width();
-        bigH = m_originalRect.height();
+        bigW = m_originalInitRect.width();
+        bigH = m_originalInitRect.height();
     } else {
         switch (type) {
         case cut_1_1:
@@ -597,13 +496,28 @@ void CGraphicsCutItem::setSize(int w, int h)
     setRect(QRectF(rect().x(), rect().y(), w, h));
 }
 
+void CGraphicsCutItem::setOriginalInitRect(const QRectF &size)
+{
+    m_originalInitRect = size;
+}
+
+void CGraphicsCutItem::setOriginalRect(const QRectF &size)
+{
+    m_originalRect = size;
+}
+
+QRectF CGraphicsCutItem::originalRect() const
+{
+    return m_originalRect;
+}
+
 QVariant CGraphicsCutItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
 {
     Q_UNUSED(change);
     if (scene() != nullptr && !scene()->views().isEmpty()) {
         scene()->views().first()->viewport()->update();
     }
-    return value;
+    return CGraphicsItem::itemChange(change, value);
 }
 
 void CGraphicsCutItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -615,7 +529,7 @@ void CGraphicsCutItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *
     painter->setClipping(false);
 
     //获取系统主题活动色
-    QColor activeColor = drawApp->systemThemeColor();
+    QColor activeColor = systemThemeColor();
 
     painter->save();
     //设置画笔参数
@@ -702,7 +616,12 @@ void CGraphicsCutItem::drawFourConner(QPainter *painter/*, QPainterPath &path, c
 {
     qreal penWidth = 1.0 / painter->worldTransform().m11();
     QRectF rct = rect().adjusted(penWidth, penWidth, -penWidth, -penWidth);
-    if (rect().width() < 15.0 || rect().height() < 15.0) {
+
+    const qreal minlenth = 24;
+    qreal showW = rect().width() * curView()->getScale();
+    qreal showH = rect().height() * curView()->getScale();
+
+    if (showW < minlenth || showH < minlenth) {
         //当裁剪区域小于拐角图片进行画笔绘制
         QPen pen(painter->pen());
         pen.setWidthF(1.0);
@@ -739,7 +658,7 @@ void CGraphicsCutItem::drawFourConner(QPainter *painter/*, QPainterPath &path, c
         //绘制左上角
         auto painterOffset  = curView()->mapFromScene(sceneBoundingRect().topLeft());
         auto painterOffset2 =  curView()->mapFromScene(sceneBoundingRect().bottomRight());
-        auto rct = QRect(painterOffset, painterOffset2);
+        rct = QRectF(painterOffset, painterOffset2);
         painter->resetTransform();
         QPixmap cornerPixmap = QIcon::fromTheme("selection_topLeft").pixmap(QSize(pixWidth, pixWidth));
         QRectF cornerRect = QRectF(painterOffset + QPointF(-offset, -offset), painterOffset + QPointF(pixWidth, pixWidth));
