@@ -29,6 +29,7 @@
 #include "cgraphicsitemselectedmgr.h"
 #include "application.h"
 #include "cgraphicsitemevent.h"
+#include "cattributeitemwidget.h"
 
 #include <DApplication>
 
@@ -46,6 +47,7 @@
 #include <QObject>
 #include <QTextDocument>
 
+REGISTITEMCLASS(CGraphicsTextItem, TextType)
 CGraphicsTextItem::CGraphicsTextItem(const QString &text, CGraphicsItem *parent)
     : CGraphicsRectItem(parent)
     , m_pTextEdit(nullptr)
@@ -63,6 +65,47 @@ CGraphicsTextItem::~CGraphicsTextItem()
     }
 }
 
+DrawAttribution::SAttrisList CGraphicsTextItem::attributions()
+{
+    DrawAttribution::SAttrisList result;
+    result << DrawAttribution::SAttri(DrawAttribution::EFontColor, textColor())
+           << DrawAttribution::SAttri(DrawAttribution::EFontFamily, fontFamily())
+           << DrawAttribution::SAttri(DrawAttribution::EFontWeightStyle,  fontStyle())
+           << DrawAttribution::SAttri(DrawAttribution::EFontSize,  fontSize());
+    return result;
+}
+
+void CGraphicsTextItem::setAttributionVar(int attri, const QVariant &var, int phase)
+{
+//    if (phase == EChangedBegin) {
+//        this->beginPreview();
+//    }
+    switch (attri) {
+    case DrawAttribution::EFontColor: {
+        setTextColor(var.value<QColor>());
+        break;
+    }
+    case DrawAttribution::EFontFamily: {
+        setFontFamily(var.toString());
+        break;
+    }
+    case DrawAttribution::EFontWeightStyle: {
+        setFontStyle(var.toString());
+        break;
+    }
+    case DrawAttribution::EFontSize: {
+        setFontSize(var.toInt());
+        break;
+    }
+    default:
+        break;
+    }
+//    if (phase == EChangedFinished) {
+//        this->endPreview();
+//    }
+    update();
+}
+
 void CGraphicsTextItem::initTextEditor(const QString &text)
 {
     m_pTextEdit = new CTextEdit(this);
@@ -112,8 +155,8 @@ void CGraphicsTextItem::changToEditState(bool selectAll)
 
     m_pTextEdit->setTextInteractionFlags(m_pTextEdit->textInteractionFlags() | (Qt::TextEditable));
 
-    if (CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getCurrentDrawToolMode() == selection ||
-            CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getCurrentDrawToolMode() == text) {
+    auto currentTool = drawScene() == nullptr ? selection : drawScene()->page()->currentTool();
+    if (currentTool == selection || currentTool == text) {
 
         if (m_pTextEdit->isHidden())
             m_pTextEdit->show();
@@ -124,6 +167,10 @@ void CGraphicsTextItem::changToEditState(bool selectAll)
             QTextCursor textCursor = m_pTextEdit->textCursor();
             textCursor.select(QTextCursor::Document);
             m_pTextEdit->setTextCursor(textCursor);
+        } else {
+            QTextCursor cursor = m_pTextEdit->textCursor();
+            cursor.movePosition(QTextCursor::End);
+            m_pTextEdit->setTextCursor(cursor);
         }
     }
 
@@ -135,10 +182,10 @@ void CGraphicsTextItem::changToEditState(bool selectAll)
     //保证自身的焦点
     toFocusEiditor();
 
-    //刷新鼠标样式
-    if (drawScene() != nullptr) {
-        drawScene()->refreshLook();
-    }
+//    //刷新鼠标样式
+//    if (drawScene() != nullptr) {
+//        drawScene()->refreshLook();
+//    }
     //进入编辑时,清空当前的撤销重做栈
     m_pTextEdit->document()->clearUndoRedoStacks();
 }
@@ -187,13 +234,14 @@ CGraphicsTextItem::EState CGraphicsTextItem::textState() const
 
 void CGraphicsTextItem::beginPreview()
 {
+    qWarning() << "CGraphicsTextItem::beginPreview()------------- ";
     if (!_isPreview) {
         _isPreview = true;
         if (m_pTextEdit != nullptr) {
             QTextCursor tCur = m_pTextEdit->textCursor();
             tCur.beginEditBlock();
             m_pTextEdit->setTextCursor(tCur);
-            qDebug() << "beginPreview avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
+            qWarning() << "beginPreview avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
         }
     } else {
         if (m_pTextEdit != nullptr) {
@@ -207,11 +255,12 @@ void CGraphicsTextItem::beginPreview()
 
 void CGraphicsTextItem::endPreview(bool revert)
 {
+    //qWarning() << "CGraphicsTextItem::endPreview()------------- ";
     if (isPreview() && m_pTextEdit != nullptr) {
         QTextCursor tCur = m_pTextEdit->textCursor();
         tCur.endEditBlock();
         m_pTextEdit->setTextCursor(tCur);
-        qDebug() << "endPreview   avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
+        //qWarning() << "endPreview   avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
     }
 
     if (revert) {
@@ -227,7 +276,7 @@ void CGraphicsTextItem::endPreview(bool revert)
             txtCursorAfter.setPosition(begin);
             txtCursorAfter.setPosition(end, QTextCursor::KeepAnchor);
             m_pTextEdit->setTextCursor(txtCursorAfter);
-            qDebug() << "endPreview1   avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
+            //qDebug() << "endPreview1   avable undo count = " << m_pTextEdit->document()->availableUndoSteps();
         }
     }
     _isPreview = false;
@@ -268,8 +317,8 @@ void CGraphicsTextItem::setRect(const QRectF &rect)
     updateShapeRecursion();
 
     //4.更新高亮
-    if (drawScene() != nullptr && isSelected())
-        drawScene()->setHighlightHelper(mapToScene(getHighLightPath()));
+    //if (drawScene() != nullptr && isSelected())
+    //drawScene()->setHighlightHelper(mapToScene(getHighLightPath()));
 }
 
 void CGraphicsTextItem::updateProxyItemPos()
@@ -313,17 +362,20 @@ void CGraphicsTextItem::setFontFamily(const QString &family)
     m_pTextEdit->setCurrentFontFamily(family);
 }
 
-QString CGraphicsTextItem::fontFamily()
+QString CGraphicsTextItem::fontFamily() const
 {
     return m_pTextEdit->currentFontFamily();
 }
 
-void CGraphicsTextItem::updateTextFormat()
+void CGraphicsTextItem::updateToDefaultTextFormat()
 {
     this->m_pTextEdit->selectAll();
-    setFont(CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getTextFont());
-    setFontStyle(CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getTextFontStyle());
-    setTextColor(CManageViewSigleton::GetInstance()->getCurView()->getDrawParam()->getTextColor());
+    if (page() != nullptr) {
+        setFontFamily(page()->defaultAttriVar(EFontFamily).toString());
+        setFontStyle(page()->defaultAttriVar(EFontWeightStyle).toString());
+        setFontSize(page()->defaultAttriVar(EFontSize).toInt());
+        setTextColor(page()->defaultAttriVar(EFontColor).value<QColor>());
+    }
 }
 
 void CGraphicsTextItem::loadGraphicsUnit(const CGraphicsUnit &data)
@@ -336,10 +388,7 @@ void CGraphicsTextItem::loadGraphicsUnit(const CGraphicsUnit &data)
         loadGraphicsRectUnit(pTextData->rect);
 
         QRectF rect(pTextData->rect.topLeft, pTextData->rect.bottomRight);
-        //qWarning() << "load width = " << rect.width() << "height = " << rect.height();
-        //setRect(rect);
 
-        //m_Font          = pTextData->font;
         setFont(pTextData->font);
 
         //手动调整过大小就意味着不需要自动根据文本调整大小了
@@ -347,9 +396,12 @@ void CGraphicsTextItem::loadGraphicsUnit(const CGraphicsUnit &data)
 
         m_pTextEdit->setHtml(pTextData->content);
 
-        //m_color = pTextData->color;
         setTextColor(pTextData->color);
 
+        m_pTextEdit->applyDefaultToFirstFormat();
+
+        m_pTextEdit->document()->clearUndoRedoStacks();
+
         setRect(rect);
     }
 }
@@ -382,6 +434,34 @@ void CGraphicsTextItem::paint(QPainter *painter, const QStyleOptionGraphicsItem
     Q_UNUSED(option)
     Q_UNUSED(widget)
 
+//    //0.会有一种情况就是图元从场景删除后,Qt依旧会掉用到paint函数,这是一个BUG,
+//    //a.怀疑是修改图元大小时,没有添加prepareGeometryChange()导致
+//    //b也可能是代理图元proyxy的添加删除交互?
+//    //当前通过该方法让其不会显示出来
+//    if (scene() == nullptr) {
+//        qWarning() << "----------- scene == nullptr but paint !!!! ";
+//        prepareGeometryChange();
+//        setRect(QRectF(0, 0, 0, 0));
+//        return;
+//    }
+
+//    //1.矩形大小不正确不绘制
+//    if (!rect().isValid())
+//        return;
+
+//    beginCheckIns(painter);
+
+//    if (textState() == EReadOnly)
+//        drawDocument(painter, m_pTextEdit->document(), this->rect());
+
+//    endCheckIns(painter);
+
+//    paintMutBoundingLine(painter, option);
+    CGraphicsRectItem::paint(painter, option, widget);
+}
+
+void CGraphicsTextItem::paintSelf(QPainter *painter, const QStyleOptionGraphicsItem *option)
+{
     //0.会有一种情况就是图元从场景删除后,Qt依旧会掉用到paint函数,这是一个BUG,
     //a.怀疑是修改图元大小时,没有添加prepareGeometryChange()导致
     //b也可能是代理图元proyxy的添加删除交互?
@@ -410,7 +490,7 @@ void CGraphicsTextItem::paint(QPainter *painter, const QStyleOptionGraphicsItem
 void CGraphicsTextItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 {
     Q_UNUSED(event)
-    changToEditState(true);
+    //changToEditState(true);
 }
 
 bool CGraphicsTextItem::isPosPenetrable(const QPointF &posLocal)
@@ -483,6 +563,8 @@ CGraphicsUnit CGraphicsTextItem::getGraphicsUnit(EDataReason reson) const
     unit.data.pText->content = this->m_pTextEdit->toHtml();
     unit.data.pText->color = /*m_color*/textColor();
 
+    //qWarning() << "content = " << unit.data.pText->content << "font size = " << m_pTextEdit->currentFontSize();
+
     return  unit;
 }
 
