@@ -54,6 +54,10 @@ enum EDdfVersion {
 
     EDdf5_9_0_3_LATER,       //5.9.0.3之后在默认head中添加了QRecF类型的数据(对所有图元都应该有一个矩形),同时开始支持组合信息的保存
 
+    EDdf5_9_9_0_LATER,       //5.9.9.0之后(include) dylayer 这个版本将画笔绘制成了一个位图,同时添加了基于位图的模糊，之前的针对图片采取的矢量模糊，现在需要调整为位图模糊
+
+    EDdf5_10_2_7_LATER,      //5_10_2_7之后 dylayer添加一个layerType用来表示图层的类型，如画笔图层或者图像图层
+
     EDdfVersionCount,
 
     EDdfCurVersion = EDdfVersionCount - 1  //最新的版本号(添加新的枚举必须添加到EDdfUnknowed和EDdfVersionCount之间)
@@ -615,6 +619,69 @@ struct SGraphicsBlurUnitData {
     }
 };
 
+struct SGraphicsEraseUnitData {
+    QPainterPath path;
+};
+struct SGraphicsFillColorUnitData {
+    QPolygonF poses;
+    QColor oldColor;
+    QColor newColor;
+};
+
+class JDyLayerCmdBase
+{
+public:
+    virtual void doCommand() = 0;
+    virtual int  cmdType() = 0;
+    virtual void serialization(QDataStream &out) {}
+    virtual void deserialization(QDataStream &in) {}
+
+    static JDyLayerCmdBase *creatCmd(int tp);
+};
+struct SDynamicLayerUnitData {
+    QList<QSharedPointer<JDyLayerCmdBase>> commands;
+    QImage baseImg;
+    bool   blocked = false;
+    int    layerType = 0;
+    friend QDataStream &operator<<(QDataStream &out, const SDynamicLayerUnitData &layUnit)
+    {
+        out << layUnit.baseImg;
+        out << layUnit.blocked;
+        out << layUnit.layerType;
+        out << layUnit.commands.count();
+        foreach (auto cmd, layUnit.commands) {
+            out << cmd->cmdType();
+            cmd->serialization(out);
+        }
+        return out;
+    }
+
+    friend QDataStream &operator>>(QDataStream &in, SDynamicLayerUnitData &layUnit)
+    {
+        in >> layUnit.baseImg;
+        in >> layUnit.blocked;
+        if (getVersion(in) >= EDdf5_10_2_7_LATER) {
+            in >> layUnit.layerType;
+        } else {
+            //0 mean is pen draw,1 mean is one imag;
+            layUnit.layerType = layUnit.baseImg.isNull() ? 0 : 1;
+        }
+        int count = 0;
+        in >> count;
+        for (int i = 0; i < count; ++i) {
+            int tp = 0;
+            in >> tp;
+            auto cmd = JDyLayerCmdBase::creatCmd(tp);
+            if (cmd != nullptr) {
+                cmd->deserialization(in);
+                QSharedPointer<JDyLayerCmdBase> p(cmd);
+                layUnit.commands.append(/*cmd*/p);
+            }
+        }
+        return in;
+    }
+};
+
 //数据封装
 union CGraphicsItemData {
     SGraphicsGroupUnitData *pGroup;               //组合图元数据
@@ -629,6 +696,10 @@ union CGraphicsItemData {
     SGraphicsPenUnitData *pPen;                   //画笔图元数据
     SGraphicsBlurUnitData *pBlur;                 //模糊图元数据
 
+    SGraphicsEraseUnitData *pErase;
+    SGraphicsFillColorUnitData *pFillColor;
+    SDynamicLayerUnitData *pDyLayer;
+
     CGraphicsItemData() {
         pGroup = nullptr;
         pRect = nullptr;
@@ -641,6 +712,9 @@ union CGraphicsItemData {
         pPic = nullptr;
         pPen = nullptr;
         pBlur = nullptr;
+        pErase = nullptr;
+        pFillColor = nullptr;
+        pDyLayer = nullptr;
     }
 };
 
@@ -650,6 +724,7 @@ struct CGraphicsUnit {
     SGraphicsUnitHead head;          //单个图元的头部信息及校验
     CGraphicsItemData data;          //单个图元的数据部分
     SGraphicsUnitTail tail;          //单个图元的尾部校验
+    QList<CGraphicsUnit> chidren;
     EDataReason       reson = ENormal;
 
     static void deepCopy(CGraphicsUnit &des, const CGraphicsUnit &source)
@@ -814,6 +889,8 @@ struct CGraphicsUnit {
             out << *(graphicsUnitData.data.pBlur);
         } else if (MgrType == graphicsUnitData.head.dataType && nullptr != graphicsUnitData.data.pGroup) {
             out << *(graphicsUnitData.data.pGroup);
+        } else if (DyLayer == graphicsUnitData.head.dataType && nullptr != graphicsUnitData.data.pDyLayer) {
+            out << *(graphicsUnitData.data.pDyLayer);
         }
 
         out << graphicsUnitData.tail;
@@ -896,6 +973,15 @@ struct CGraphicsUnit {
             }
             break;
         }
+        case DyLayer: {
+            EDdfVersion version = getVersion(in);
+            if (version >= EDdf5_9_9_0_LATER) {
+                SDynamicLayerUnitData *pData = new SDynamicLayerUnitData();
+                in >> *pData;
+                graphicsUnitData.data.pDyLayer = pData;
+            }
+            break;
+        }
         default:
             break;
 
@@ -970,11 +1056,17 @@ struct CGraphicsUnit {
             break;
         }
         case MgrType: {
-            if (data.pBlur != nullptr) {
+            if (data.pGroup != nullptr) {
                 delete data.pGroup;
             }
             break;
         }
+        case DyLayer: {
+            if (data.pDyLayer != nullptr) {
+                delete data.pDyLayer;
+            }
+            break;
+        }
         default:
             break;
 
