@@ -157,13 +157,23 @@ public:
         }
         return _dialog;
     }
-    QString execFileSelectDialog(const QString &defualFileName, bool toddf = true)
+
+    QString execFileSelectDialog(const QString &defualFileName, bool toddf = true, QString file = "")
     {
         if (toddf) {
             FileSelectDialog dialog(_borad);
-            dialog.selectFile(defualFileName);
-            dialog.setNameFilter("*.ddf");
+            dialog.setNameFilters(drawApp->writableFormatNameFilters());
+            dialog.selectNameFilter(drawApp->defaultFileDialogNameFilter());
+
+            if (!file.isEmpty()) {
+                dialog.selectFile(file);
+                dialog.setDirectory(QFileInfo(file).dir().absolutePath());
+            } else {
+                dialog.selectFile(defualFileName);
+                dialog.setDirectory(drawApp->defaultFileDialogPath());
+            }
             dialog.exec();
+
             return dialog.resultFile();
         }
         CExportImageDialog dialog(_borad);
@@ -529,13 +539,21 @@ bool Page::save(const QString &file)
 
     if (_context != nullptr) {
         QString f = file.isEmpty() ? _context->file() : file;
-        if (f.isEmpty()) {
-            f = borad()->d_pri()->execFileSelectDialog(_context->name());
+
+        if (f.isEmpty() || !QFileInfo(f).dir().exists()) {
+            f = borad()->d_pri()->execFileSelectDialog(_context->name(), true, f);
         }
+
         if (f.isEmpty())
             return false;
-        bool result = _context->save(f);
 
+        //如果当前格式不支持写，弹出另存为窗口
+        QString writableFormats = "." + drawApp->writableFormats().join(".") + ".";
+        if (!writableFormats.contains("." + QFileInfo(f).suffix().toLower() + ".")) {
+            return saveAs();
+        }
+
+        bool result = _context->save(f);
 
         qWarning() << "save result = " << (borad()->fileHander()->lastError()) << (borad()->fileHander()->lastErrorDescribe());
         if (!result) {
@@ -764,6 +782,9 @@ static int noticeFileContextChanged(Page *page, DrawBoard *borad)
 
 DrawBoard::DrawBoard(QWidget *parent): DWidget(parent)
 {
+    setAttribute(Qt::WA_InputMethodEnabled);
+    setAttribute(Qt::WA_KeyCompression);
+
     _pPrivate = new DrawBoard_private(this);
 
     connect(QApplication::clipboard(), &QClipboard::dataChanged, this, [ = ]() {
@@ -1275,9 +1296,13 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                 loaded = true;
                 QMetaObject::invokeMethod(this, [ =, &lastChoice]() {
 
+                    bool bNewPage = false;
                     if (nullptr == currentPage()) {
                         addPage("");
                         currentPage()->setPageRect(QRectF(QPointF(0, 0), img.size()));
+                        currentPage()->setFile(path);
+                        currentPage()->context()->setDirty(false);
+                        bNewPage = true;
                     }
 
                     if (0 == loadTypeForImage) {
@@ -1290,14 +1315,14 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                                          );
                         currentPage()->setPageRect(newRect);
                         currentPage()->context()->scene()->clearSelectGroup();
-                        currentPage()->context()->addImage(img, QPointF(), QRectF(), true, true);
+                        currentPage()->context()->addImage(img, QPointF(), QRectF(), !bNewPage, true);
                         currentPage()->adjustViewScaleRatio();
                     } else if (1 == loadTypeForImage) {
                         QPointF pos;
                         QRectF rect;
                         if (adaptImgPosAndRect(currentPage()->scene(), info.fileName(), img, pos, rect, lastChoice)) {
                             currentPage()->context()->scene()->clearSelectGroup();
-                            currentPage()->context()->addImage(img, pos, rect, true, true);
+                            currentPage()->context()->addImage(img, pos, rect, !bNewPage, true);
                         }
                     }
 
